@@ -321,57 +321,6 @@ typedef struct _MHW_VDBOX_MPEG2_PIC_STATE
     uint32_t                                dwFrameBitRateMaxUnit;
 } MHW_VDBOX_MPEG2_PIC_STATE, *PMHW_VDBOX_MPEG2_PIC_STATE;
 
-typedef struct _MHW_VDBOX_AVC_SLICE_STATE
-{
-    PCODEC_PIC_ID                           pAvcPicIdx;
-    PMOS_RESOURCE                           presDataBuffer;
-    uint32_t                                dwDataBufferOffset;
-    uint32_t                                dwOffset;
-    uint32_t                                dwLength;
-    uint32_t                                dwSliceIndex;
-    bool                                    bLastSlice;
-    uint32_t                                dwTotalBytesConsumed;
-
-    // Decoding Only
-    PCODEC_AVC_PIC_PARAMS                   pAvcPicParams;
-    PCODEC_MVC_EXT_PIC_PARAMS               pMvcExtPicParams;
-    PCODEC_AVC_SLICE_PARAMS                 pAvcSliceParams;
-    uint32_t                                dwNextOffset;
-    uint32_t                                dwNextLength;
-    bool                                    bIntelEntrypointInUse;
-    bool                                    bPicIdRemappingInUse;
-    bool                                    bShortFormatInUse;
-    bool                                    bPhantomSlice;
-    uint8_t                                 ucDisableDeblockingFilterIdc;
-    uint8_t                                 ucSliceBetaOffsetDiv2;
-    uint8_t                                 ucSliceAlphaC0OffsetDiv2;
-
-    // Encoding Only
-    PCODEC_AVC_ENCODE_SEQUENCE_PARAMS       pEncodeAvcSeqParams;
-    PCODEC_AVC_ENCODE_PIC_PARAMS            pEncodeAvcPicParams;
-    PCODEC_AVC_ENCODE_SLICE_PARAMS          pEncodeAvcSliceParams;
-    PBSBuffer                               pBsBuffer;
-    PCODECHAL_NAL_UNIT_PARAMS              *ppNalUnitParams;
-    PMHW_BATCH_BUFFER                       pBatchBufferForPakSlices;
-    bool                                    bSingleTaskPhaseSupported;
-    bool                                    bFirstPass;
-    bool                                    bLastPass;
-    bool                                    bBrcEnabled;
-    bool                                    bRCPanicEnable;
-    bool                                    bInsertBeforeSliceHeaders;
-    bool                                    bAcceleratorHeaderPackingCaps;
-    uint32_t                                dwBatchBufferForPakSlicesStartOffset;
-    uint32_t                                uiSkipEmulationCheckCount;
-    uint32_t                                dwRoundingValue;
-    uint32_t                                dwRoundingIntraValue;
-    bool                                    bRoundingInterEnable;
-    uint16_t                                wFrameFieldHeightInMB;  // Frame/field Height in MB
-    bool                                    bVdencInUse;
-    bool                                    bVdencNoTailInsertion;
-    bool                                    oneOnOneMapping = false;
-    bool                                    bFullFrameData;
-} MHW_VDBOX_AVC_SLICE_STATE, *PMHW_VDBOX_AVC_SLICE_STATE;
-
 typedef struct _MHW_VDBOX_AVC_DPB_PARAMS
 {
     PCODEC_AVC_PIC_PARAMS                   pAvcPicParams;
@@ -399,16 +348,18 @@ typedef struct _MHW_VDBOX_AVC_DIRECTMODE_PARAMS
 
 typedef struct _MHW_VDBOX_AVC_REF_IDX_PARAMS
 {
-    CODEC_PICTURE                   CurrPic;
-    bool                            isEncode;
-    uint32_t                        uiList;
-    uint32_t                        uiNumRefForList;
-    CODEC_PICTURE                   RefPicList[2][32];
-    PCODEC_PIC_ID                   pAvcPicIdx;
-    void                            **avcRefList;
-    bool                            bIntelEntrypointInUse;
-    bool                            bPicIdRemappingInUse;
-    bool                            oneOnOneMapping = false;
+    CODEC_PICTURE                   CurrPic               = {};
+    uint32_t                        uiNumRefForList[2]    = {};
+    CODEC_PICTURE                   RefPicList[2][32]     = {};
+    PCODEC_PIC_ID                   pAvcPicIdx            = {};
+    uint32_t                        uiList                = 0;
+    void                            **avcRefList          = nullptr;
+    bool                            isEncode              = false;
+    bool                            bVdencInUse           = false;
+    bool                            bIntelEntrypointInUse = false;
+    bool                            bPicIdRemappingInUse  = false;
+    bool                            oneOnOneMapping       = false;
+    bool                            bDummyReference       = false;
 } MHW_VDBOX_AVC_REF_IDX_PARAMS, *PMHW_VDBOX_AVC_REF_IDX_PARAMS;
 
 typedef struct _MHW_VDBOX_PIC_ID_PARAMS
@@ -630,16 +581,6 @@ protected:
         mfxDecoderModeIt    = 1
     };
 
-    //!
-    //! \struct   VDEncFrameDeltaTable
-    //! \brief    VD encode frame delta table
-    //!
-    struct VDEncFrameDeltaTable
-    {
-        uint32_t PFrameDelta;
-        uint32_t IFrameDelta;
-    };
-
     static const uint16_t m_mpeg2DefaultIntraQuantizerMatrix[64]; //!< MPEG2 default quantization matrix for intra macroblock
     static const uint16_t m_mpeg2DefaultNonIntraQuantizerMatrix[64]; //!< MPEG2 default quantization matrix for inter macroblock
     static const uint32_t m_mpeg2SliceDeltaQPMax[4]; //! MPEG2 slice delta QP max value
@@ -656,9 +597,6 @@ protected:
     static const uint32_t m_mfxErrorFlagsMask = 0xFBFF; //!< Mfx error flags mask
                                                         //!< Bit 10 of MFD_ERROR_STATUS register is set to a random value during RC6, so it is not used
 
-    static const VDEncFrameDeltaTable m_vdEncFrameDelta100PercentTab[CODEC_AVC_NUM_QP];
-    static const VDEncFrameDeltaTable m_vdEncFrameDelta90PercentTab[CODEC_AVC_NUM_QP];
-
     static const uint32_t m_log2WeightDenomDefault = 5; //!< Default value of luma/chroma_log2_weight_denoms
     static const uint32_t m_mpeg2WeightScaleSize = 16; //!< Size of MPEG2 weight scale
 
@@ -1052,6 +990,36 @@ public:
         }
     }
 
+    //!
+    //! \brief    Convert from Mfx mmio registers to MI mmio register
+    //!
+    //! \param    [in] index
+    //!           mmio registers index.
+    //! \param    [in] mmioRegister
+    //!           reference to MHW_MI_MMIOREGISTERS.
+    //!
+    //! \return   [out] bool
+    //!           return true if mmio register if found, otherwise return false
+    //!
+    inline bool ConvertToMiRegister(MHW_VDBOX_NODE_IND index, MHW_MI_MMIOREGISTERS &mmioRegister)
+    {
+        MmioRegistersMfx* mfxMmioReg = GetMmioRegisters(index);
+        if (mfxMmioReg)
+        {
+            mmioRegister.generalPurposeRegister0LoOffset = mfxMmioReg->generalPurposeRegister0LoOffset;
+            mmioRegister.generalPurposeRegister0HiOffset = mfxMmioReg->generalPurposeRegister0HiOffset;
+            mmioRegister.generalPurposeRegister4LoOffset = mfxMmioReg->generalPurposeRegister4LoOffset;
+            mmioRegister.generalPurposeRegister4HiOffset = mfxMmioReg->generalPurposeRegister4HiOffset;
+            mmioRegister.generalPurposeRegister11LoOffset = mfxMmioReg->generalPurposeRegister11LoOffset;
+            mmioRegister.generalPurposeRegister11HiOffset = mfxMmioReg->generalPurposeRegister11HiOffset;
+            mmioRegister.generalPurposeRegister12LoOffset = mfxMmioReg->generalPurposeRegister12LoOffset;
+            mmioRegister.generalPurposeRegister12HiOffset = mfxMmioReg->generalPurposeRegister12HiOffset;
+            return true;
+        }
+        else
+            return false;
+    }
+
     //!
     //! \brief    Get brc pak passes num
     //! \details  Get brc pak passes num in mfx interface
